@@ -65,6 +65,7 @@ __all__ = (
     "CreateClusterResponseTypeDef",
     "CreateConfigurationResponseTypeDef",
     "DeleteClusterResponseTypeDef",
+    "DeleteConfigurationResponseTypeDef",
     "DescribeClusterOperationResponseTypeDef",
     "DescribeClusterResponseTypeDef",
     "DescribeConfigurationResponseTypeDef",
@@ -85,6 +86,7 @@ __all__ = (
     "UpdateBrokerStorageResponseTypeDef",
     "UpdateClusterConfigurationResponseTypeDef",
     "UpdateClusterKafkaVersionResponseTypeDef",
+    "UpdateConfigurationResponseTypeDef",
     "UpdateMonitoringResponseTypeDef",
 )
 
@@ -234,6 +236,7 @@ ConfigurationTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
+        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
     },
 )
 
@@ -370,6 +373,7 @@ CreateConfigurationResponseTypeDef = TypedDict(
         "CreationTime": datetime,
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
+        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
     },
     total=False,
 )
@@ -380,6 +384,12 @@ DeleteClusterResponseTypeDef = TypedDict(
     total=False,
 )
 
+DeleteConfigurationResponseTypeDef = TypedDict(
+    "DeleteConfigurationResponseTypeDef",
+    {"Arn": str, "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"]},
+    total=False,
+)
+
 DescribeClusterOperationResponseTypeDef = TypedDict(
     "DescribeClusterOperationResponseTypeDef",
     {"ClusterOperationInfo": "ClusterOperationInfoTypeDef"},
@@ -399,6 +409,7 @@ DescribeConfigurationResponseTypeDef = TypedDict(
         "KafkaVersions": List[str],
         "LatestRevision": "ConfigurationRevisionTypeDef",
         "Name": str,
+        "State": Literal["ACTIVE", "DELETING", "DELETE_FAILED"],
     },
     total=False,
 )
@@ -501,6 +512,12 @@ UpdateClusterKafkaVersionResponseTypeDef = TypedDict(
     total=False,
 )
 
+UpdateConfigurationResponseTypeDef = TypedDict(
+    "UpdateConfigurationResponseTypeDef",
+    {"Arn": str, "LatestRevision": "ConfigurationRevisionTypeDef"},
+    total=False,
+)
+
 UpdateMonitoringResponseTypeDef = TypedDict(
     "UpdateMonitoringResponseTypeDef", {"ClusterArn": str, "ClusterOperationArn": str}, total=False
 )
